/********************************************************************
 defaults.h : compilation defaults for mps

 Here we define how mps will behave by default, i.e.
 when the user doesn't give it any options.
 The comments next to different entries should be
 self-explanatory.
 
 You may want to read the man page before proceeding.
 To do that, enter:

 	nroff -man mps.1 | more

 from the command prompt.

 You can also generate a printable, PostScript version of
 the man page (assuming you have groff on your system) by
 entering "make psman" and copying the resulting file
 (mps.1.ps) to your PostScript printer.

 (You may also want to make a backup copy of this file, 
  defaults.h, just in case.)

 Except where otherwise indicated, all measurements are in points.
 	72 points = 1 inch
 	360 points = 127 milimeters

 Copyright (C) 1999, Richard Urena.  All rights reserved.

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.   You can find the GNU
 General Public License in the file COPYING in the source directory,
 or at http://www.gnu.org

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 ********************************************************************/

#ifndef MPS__DEFAULTS
#define MPS__DEFAULTS

/*
 *	define the default font
 *		0 = Courier 9 point
 *		1 = Courier 10 point
 *		2 = Courier 12 point
*/
#define	MPS__DEFAULTFONT	1


/*
 *	default paper
 *		0 = letter
 *		1 = legal
 *		2 = a4
*/
#define	MPS__DEFAULTPAPER	0


/*
 *	should mps assume double-sided printing by default?
 *		1 = yes
 *		0 = no
*/
#define	MPS__ASSUMEDUPLEX	0


/*
 * should we fold long lines?  (if not, that means truncate them)
 *		1 = yes
 *		0 = no
*/
#define	MPS__FOLDLONG	1


/*
 * should mps print page numbers by default?
 *		1 = yes
 *		0 = no
*/
#define	MPS__PAGENUMBERS	0


/*
 * and if so, where to start numbering?
*/
#define	MPS__FIRSTPAGENO	1


/*
 * what is the distance between the bottom of the page number
 * (if printed) and the physical bottom of the page?
*/
#define	MPS__BOTTOMGUTTER	20.0



/*
 * default measurement units, from the user's point of view.
 *
 * in other words, although mps operates internally in points,
 * when the user specifies things like margins as an option,
 * what units will they be using by default?
 *
 *		0 = inches
 *		1 = points
 *		2 = milimiters
 *		3 = centimeters
*/
#define	MPS__DEFAULTUNITS	0



/*
 * now specify the margins, in terms of the default measurement
 * units given above  (e.g., one inch all-around)
*/
#define	MPS__MARGINRIGHT	1.0
#define	MPS__MARGINLEFT		1.0
#define	MPS__MARGINTOP		1.0
#define	MPS__MARGINBOTTOM	1.0



/*
 * expand tabs to how many spaces?
 *		(an integer between 1 and 16)
*/
#define	MPS__TABSTOP	8



/***** you probably don't want to change anything below this line *****/


/*
 *	version info
*/
#define	MPS__VERSIONMAJOR	2
#define	MPS__VERSIONMINOR	1
#define	MPS__PATCHLEVEL		0


/*
 *	specify the maximum input and output line length.
*/
#define	MPS__MAXLINESIZE	4096


/*
 * if we need to fold long lines, we'll try to fold them
 * at a whitespace; up to a limit.  What is that limit,
 * in characters?
*/
#define	MPS__CLEANBREAKLIMIT	12


/*
 *	some global symbolic constant(s)
*/
#define	MPS__EMPTYSTRING	""
#define	MPS__PAGEEJECT	'\014'
#define	MPS__CTRLD	'\004'


/*
 * which character indicates an option in the command line
 *
*/
#define	MPS__OPTIONPREFIX	'-'


/*
 * should mps stop printing the current file if a Ctrl-D
 * is encountered?  (default is no, uncomment the #define
 * if you want this)
 *
 * NOTE:  if you change this, you should also uncomment
 * a section of the man page (file: mps.1) that is commented
 * out.
*/
/*
#define	MPS__QUITONCTRLD
*/


#endif
